summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorAttila Molnar <attilamolnar@hush.com>2016-02-26 15:59:20 +0100
committerAttila Molnar <attilamolnar@hush.com>2016-02-26 15:59:20 +0100
commit725c954efbdaca99701412e640a1a762b36a5f48 (patch)
treec20704faf5aeba6ead8aeb4af245b6048cf26cc2 /include
parent2a16373ca12e0b4bbe72a487f1620a0d027414be (diff)
Send WHO reply numerics with User::WriteNumeric(), pass Numeric::Numeric objects to the OnSendWhoLine hook
Diffstat (limited to 'include')
-rw-r--r--include/modules.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/modules.h b/include/modules.h
index a349a5d2a..46aa13e40 100644
--- a/include/modules.h
+++ b/include/modules.h
@@ -990,10 +990,10 @@ class CoreExport Module : public classbase, public usecountbase
* @param params The parameters to the /WHO query
* @param user The user that this line of the query is about
* @param memb The member shown in this line, NULL if no channel is in this line
* @param line The raw line to send; modifiable.
* @param Return MOD_RES_PASSTHRU to allow the line to be displayed, MOD_RES_DENY to hide it
*/
- virtual ModResult OnSendWhoLine(User* source, const std::vector<std::string>& params, User* user, Membership* memb, std::string& line);
+ virtual ModResult OnSendWhoLine(User* source, const std::vector<std::string>& params, User* user, Membership* memb, Numeric::Numeric& numeric);
/** Called whenever a local user's IP is set for the first time, or when a local user's IP changes due to
* a module like m_cgiirc changing it.
@@ -990,10 +990,10 @@ class CoreExport Module : public classbase, public usecountbase
* @param user The user that this line of the query is about
* @param memb The member shown in this line, NULL if no channel is in this line
- * @param line The raw line to send; modifiable.
+ * @param numeric Numeric to send; modifiable.
* @param Return MOD_RES_PASSTHRU to allow the line to be displayed, MOD_RES_DENY to hide it
*/